<?php
/*
Plugin Name: Proper PHP Include
Plugin URI: http://www.tipsandtricks-hq.com
Description: Properly include PHP code into posts and pages, and maybe even widgets, in WordPress
Version: 1.0
Author: Tips and Tricks HQ
Author URI: http://www.tipsandtricks-hq.com
*/

class tthq_proper_php_include_shortcode_class
{

   /**
     * Handler for [tthq_include_file] shortcodes
     * Processes an include file that contains custom PHP code.
     * @param   array $atts         Attributes passed in by shortcode
     * @param   string $content     Contents of shortcode
     * @return  string              Contents of include file
     */
    function tthq_proper_php_include_file($atts, $content="")
    {
	    // Check the input and override the default tthq_file NULL.
		extract(shortcode_atts(array('tthq_file' => 'NULL'), $atts));
		extract(shortcode_atts(array('tthq_path' => 'NULL'), $atts));

		if ($tthq_path=='NULL')
		{
		    $tthq_proper_php_include_options = get_option('tthq_proper_php_include_options_group');
		    $tthq_path = $tthq_proper_php_include_options['tthq_file_path_string'];
		    if ($tthq_path=='')
		    {
		        $tthq_path = TEMPLATEPATH.'/';
		    }
		}

		// Check if the tthq_file was specified and if the file exists
		if ($tthq_file!='NULL' && file_exists($tthq_path.$tthq_file))
		{
		    // Turn on output buffering to capture script output.
		    ob_start();

		    // Include the specified file.
		    include($tthq_path.$tthq_file);

		    // Assign the file output to $content variable and clean buffer.
		    $content = ob_get_clean();

		    // Return the $content
			return $content;
		}
	}

}

function tthq_proper_php_include_menu() {
	add_options_page( 'Proper PHP Include Options', 'Proper PHP Include', 'manage_options', 'tthq-proper-php-include-menu-options', 'tthq_proper_php_include_menu_options' );
	add_action( 'admin_init', 'register_tthq_proper_php_include_setting' );
}

function register_tthq_proper_php_include_setting() {
	register_setting( 'tthq_proper_php_include_options_group', 'tthq_proper_php_include_options_group', '' );
	add_settings_section('tthq_proper_php_include_main', '', 'tthq_proper_php_include_section_text', 'tthq-proper-php-include-menu-options');
	add_settings_field('tthq_file_path_string', 'Include File Path<br />(include trailing slash)', 'tthq_proper_php_include_setting_string', 'tthq-proper-php-include-menu-options', 'tthq_proper_php_include_main');
}

function tthq_proper_php_include_section_text() {
    echo '<p>Enter the path to your PHP files below. If left blank, will default to current template path: <strong>'.TEMPLATEPATH.'/</strong></p>';
}

function tthq_proper_php_include_setting_string() {
    $options = get_option('tthq_proper_php_include_options_group');
    echo "<input id='tthq_file_path_string' name='tthq_proper_php_include_options_group[tthq_file_path_string]' size='50' type='text' value='{$options['tthq_file_path_string']}' />";
}

function tthq_proper_php_include_menu_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}
	echo '<div class="wrap">';
	screen_icon();
	echo '<h2>Proper PHP Include Options</h2>';
	echo '<form method="post" action="options.php">';
	settings_fields( 'tthq_proper_php_include_options_group' );
	do_settings_sections('tthq-proper-php-include-menu-options');
    submit_button();
	echo '</form>';
	echo '</div>';
}

// Instantiate an object of tthq_proper_php_include_shortcode_class.
$tthq_proper_php_include_shortcode_class = new tthq_proper_php_include_shortcode_class();

// Add shortcodes.
add_shortcode('tthq_include_file', array($tthq_proper_php_include_shortcode_class, 'tthq_proper_php_include_file'));
add_filter('widget_text', 'do_shortcode');

// Add actions for options panel.
add_action( 'admin_menu', 'tthq_proper_php_include_menu' );
